<?php
/**
 * Page title map.
 *
 * @package Woodmart
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'woodmart_vc_map_page_title' ) ) {
	/**
	 * Page title map.
	 */
	function woodmart_vc_map_page_title() {
		if ( ! shortcode_exists( 'woodmart_page_title' ) ) {
			return;
		}

		vc_map(
			array(
				'base'        => 'woodmart_page_title',
				'name'        => esc_html__( 'Page title', 'woodmart' ),
				'category'    => esc_html__( '[XTemos] WooCommerce', 'woodmart' ),
				'description' => esc_html__( 'Main page title section', 'woodmart' ),
				'icon'        => WOODMART_ASSETS . '/images/vc-icon/wc-icons/wc-page-title.svg',
				'params'      => array(
					array(
						'group'      => esc_html__( 'Style', 'woodmart' ),
						'type'       => 'woodmart_css_id',
						'param_name' => 'woodmart_css_id',
					),

					array(
						'heading'     => esc_html__( 'Full width', 'woodmart' ),
						'group'       => esc_html__( 'Style', 'woodmart' ),
						'type'        => 'woodmart_switch',
						'param_name'  => 'full_width',
						'true_state'  => 'yes',
						'false_state' => 'no',
						'default'     => 'no',
					),

					array(
						'heading'    => esc_html__( 'Container width', 'woodmart' ),
						'group'      => esc_html__( 'Style', 'woodmart' ),
						'type'       => 'wd_slider',
						'param_name' => 'container_width',
						'selectors'  => array(
							'{{WRAPPER}} .container' => array(
								'max-width: {{VALUE}}{{UNIT}};',
							),
						),
						'devices'    => array(
							'desktop' => array(
								'value' => '',
								'unit'  => 'px',
							),
						),
						'range'      => array(
							'px' => array(
								'min'  => 300,
								'max'  => 3000,
								'step' => 1,
							),
						),
					),

					array(
						'heading'    => esc_html__( 'CSS box', 'woodmart' ),
						'group'      => esc_html__( 'Design Options', 'js_composer' ),
						'type'       => 'css_editor',
						'param_name' => 'css',
					),
					woodmart_get_vc_responsive_spacing_map(),

					// Width option (with dependency Columns option, responsive).
					woodmart_get_responsive_dependency_width_map( 'responsive_tabs' ),
					woodmart_get_responsive_dependency_width_map( 'width_desktop' ),
					woodmart_get_responsive_dependency_width_map( 'custom_width_desktop' ),
					woodmart_get_responsive_dependency_width_map( 'width_tablet' ),
					woodmart_get_responsive_dependency_width_map( 'custom_width_tablet' ),
					woodmart_get_responsive_dependency_width_map( 'width_mobile' ),
					woodmart_get_responsive_dependency_width_map( 'custom_width_mobile' ),
				),
			)
		);
	}

	add_action( 'vc_before_init', 'woodmart_vc_map_page_title' );
}
